CommandBuffer

Trait CommandBuffer 

pub trait CommandBuffer {
    // Required methods
    fn new_line(&mut self);
    fn print(&mut self, text: &str);
    fn set_formatting(&mut self, formatting: &Formatting);
    fn reset_formatting(&mut self);
}
Represents the set of rendering commands

Required Methods

fn new_line(&mut self)

Move the cursor to the new line

fn print(&mut self, text: &str)

Print the text to the screen at the current cursor position

fn set_formatting(&mut self, formatting: &Formatting)

Set the given formatting to all text before the next reset_formatting call

fn reset_formatting(&mut self)

Resets the previously set formatting to default

Implementors