Options

Struct Options 

pub struct Options<T> { /* private fields */ }
A helper struct for the multi-option prompts

Implementations

Source

impl<T> Options<T>
where T: Into<String> + Clone,

pub fn from_iter<I>(iter: I) -> Self
where I: Iterator<Item = T>,

Create Options from an iterator over a type that is convertable to String

Source

impl<T> Options<T>

pub fn from_iter_transformed<I, F>(iter: I, transformation: F) -> Self
where I: Iterator<Item = T>, F: Fn(&T) -> String,

Create Options from an arbitrary type using provided transformation function to String

pub fn filter(&mut self, filter: &str)

Filter options using provided string slice

pub fn filtered_options(&self) -> &[usize]

Retrieve the indices of all options that satisfy the last applied filter

pub fn all_options_mut(&mut self) -> &mut Vec<T>

Get a mutable reference to the vector all available options

pub fn transformed_options(&self) -> &[String]

Get a reference to all options in their string representation