Selection

Struct Selection 

pub struct Selection<T> { /* private fields */ }
Prompt that allows to select one option from the given list. Supports filtering and moving the selection with arrow keys.

use cli_prompts::{
     prompts::{Selection, AbortReason},
     DisplayPrompt,
};

fn main() {
    let social_media = [
        "Facebook",
        "Instagram",
        "Twitter",
        "Snapchat"
    ];

    let prompt = Selection::new("Where you want to post?", social_media.into_iter())
                    .displayed_options_count(3);
    let selection : Result<&str, AbortReason> = prompt.display();
    match selection {
        Ok(media) => println!("Posting to {}", media),
        Err(abort_reason) => println!("Prompt is aborted because of {:?}", abort_reason),
    }
}

Implementations

Source

impl<T> Selection<T>

pub fn new<S, I>(label: S, options: I) -> Self
where T: Into<String> + Clone, S: Into<String>, I: Iterator<Item = T>,

Create new prompt with the given label and the iterator over a type that is convertable to String

Examples found in repository?
examples/general.rs (line 46)
21fn main() {
22    let desserts = [
23        "Tiramisu",
24        "Cheesecake",
25        "Brownee",
26        "Cookie",
27        "Jelly",
28        "Chupa-Chups",
29        "Pudding",
30    ];
31    let subjects = [
32        "Physics",
33        "Math",
34        "Polish",
35        "English",
36        "Sport",
37        "Geography",
38        "History",
39    ];
40    let cars = [CarModel::Audi, CarModel::BMW, CarModel::Chevrolet];
41
42    let input_prompt = Input::new("Enter your name", |s| Ok(s.to_string()))
43        .default_value("John")
44        .help_message("Please provide your real name");
45    let confirmation = Confirmation::new("Do you want a cup of coffee?").default_positive(true);
46    let dessert_selection = Selection::new("Your favoite dessert", desserts.into_iter());
47    let car_selection =
48        Selection::new_with_transformation("Your car model", cars.into_iter(), car_to_string);
49    let subjects_selection =
50        Multiselect::new("What are your favourite subjects", subjects.into_iter());
51
52    let name = input_prompt.display();
53    let is_coffee = confirmation.display();
54    let dessert = dessert_selection.display();
55    let car = car_selection.display();
56    let subjects = subjects_selection.display();
57
58    println!("Name: {:?}", name);
59    println!("Is coffee: {:?}", is_coffee);
60    println!("Dessert: {:?}", dessert);
61    println!("Car: {:?}", car);
62    println!("Subjects: {:?}", subjects);
63}
Source

impl<T> Selection<T>

pub fn new_with_transformation<S, I, F>( label: S, options: I, transformation: F, ) -> Self
where S: Into<String>, I: Iterator<Item = T>, F: Fn(&T) -> String,

Create new prompt with the given label and a transformation function that will convert the iterator items to strings

Examples found in repository?
examples/general.rs (line 48)
21fn main() {
22    let desserts = [
23        "Tiramisu",
24        "Cheesecake",
25        "Brownee",
26        "Cookie",
27        "Jelly",
28        "Chupa-Chups",
29        "Pudding",
30    ];
31    let subjects = [
32        "Physics",
33        "Math",
34        "Polish",
35        "English",
36        "Sport",
37        "Geography",
38        "History",
39    ];
40    let cars = [CarModel::Audi, CarModel::BMW, CarModel::Chevrolet];
41
42    let input_prompt = Input::new("Enter your name", |s| Ok(s.to_string()))
43        .default_value("John")
44        .help_message("Please provide your real name");
45    let confirmation = Confirmation::new("Do you want a cup of coffee?").default_positive(true);
46    let dessert_selection = Selection::new("Your favoite dessert", desserts.into_iter());
47    let car_selection =
48        Selection::new_with_transformation("Your car model", cars.into_iter(), car_to_string);
49    let subjects_selection =
50        Multiselect::new("What are your favourite subjects", subjects.into_iter());
51
52    let name = input_prompt.display();
53    let is_coffee = confirmation.display();
54    let dessert = dessert_selection.display();
55    let car = car_selection.display();
56    let subjects = subjects_selection.display();
57
58    println!("Name: {:?}", name);
59    println!("Is coffee: {:?}", is_coffee);
60    println!("Dessert: {:?}", dessert);
61    println!("Car: {:?}", car);
62    println!("Subjects: {:?}", subjects);
63}
pub fn displayed_options_count(self, options_count: u16) -> Self

Set maximum number of options that can be displayed on the screen

pub fn style(self, style: SelectionStyle) -> Self

Set the prompt style