LabelStyle

Struct LabelStyle 

pub struct LabelStyle { /* private fields */ }
Style for the common part of all prompts: the prompt itself.

Implementations

Source

impl LabelStyle

pub fn prefix<S: Into<String>>(self, p: S) -> Self

Sets the string that is displayed before the user’s input

Examples found in repository?
examples/styling.rs (line 19)
17fn main() -> Result<()> {
18    let label_style = LabelStyle::default()
19        .prefix("*")
20        .prefix_formatting(Formatting::default().foreground_color(Color::Cyan))
21        .prompt_formatting(
22            Formatting::default()
23                .bold()
24                .underline()
25                .foreground_color(Color::Magenta),
26        );
27    let input_formatting = Formatting::default().foreground_color(Color::Cyan);
28    let submitted_formatting = Formatting::default().foreground_color(Color::DarkCyan);
29
30    let name = Input::new("Enter your name", name_validation)
31        .style(
32            InputStyle::default()
33                .label_style(label_style.clone())
34                .input_formatting(input_formatting.clone())
35                .submitted_formatting(submitted_formatting.clone()),
36        )
37        .display();
38    let coffee = Confirmation::new("Do you want a cup of coffee")
39        .style(
40            ConfirmationStyle::default()
41                .label_style(label_style.clone())
42                .input_formatting(input_formatting.clone())
43                .submitted_formatting(submitted_formatting.clone()),
44        )
45        .display();
46
47    println!("Name: {:?}", name);
48    println!("Coffee: {:?}", coffee);
49
50    Ok(())
51}
pub fn prefix_formatting(self, f: Formatting) -> Self

Sets formatting for the prefix string

Examples found in repository?
examples/styling.rs (line 20)
17fn main() -> Result<()> {
18    let label_style = LabelStyle::default()
19        .prefix("*")
20        .prefix_formatting(Formatting::default().foreground_color(Color::Cyan))
21        .prompt_formatting(
22            Formatting::default()
23                .bold()
24                .underline()
25                .foreground_color(Color::Magenta),
26        );
27    let input_formatting = Formatting::default().foreground_color(Color::Cyan);
28    let submitted_formatting = Formatting::default().foreground_color(Color::DarkCyan);
29
30    let name = Input::new("Enter your name", name_validation)
31        .style(
32            InputStyle::default()
33                .label_style(label_style.clone())
34                .input_formatting(input_formatting.clone())
35                .submitted_formatting(submitted_formatting.clone()),
36        )
37        .display();
38    let coffee = Confirmation::new("Do you want a cup of coffee")
39        .style(
40            ConfirmationStyle::default()
41                .label_style(label_style.clone())
42                .input_formatting(input_formatting.clone())
43                .submitted_formatting(submitted_formatting.clone()),
44        )
45        .display();
46
47    println!("Name: {:?}", name);
48    println!("Coffee: {:?}", coffee);
49
50    Ok(())
51}
pub fn prompt_formatting(self, f: Formatting) -> Self

Sets formatting for the user input string

Examples found in repository?
examples/styling.rs (lines 21-26)
17fn main() -> Result<()> {
18    let label_style = LabelStyle::default()
19        .prefix("*")
20        .prefix_formatting(Formatting::default().foreground_color(Color::Cyan))
21        .prompt_formatting(
22            Formatting::default()
23                .bold()
24                .underline()
25                .foreground_color(Color::Magenta),
26        );
27    let input_formatting = Formatting::default().foreground_color(Color::Cyan);
28    let submitted_formatting = Formatting::default().foreground_color(Color::DarkCyan);
29
30    let name = Input::new("Enter your name", name_validation)
31        .style(
32            InputStyle::default()
33                .label_style(label_style.clone())
34                .input_formatting(input_formatting.clone())
35                .submitted_formatting(submitted_formatting.clone()),
36        )
37        .display();
38    let coffee = Confirmation::new("Do you want a cup of coffee")
39        .style(
40            ConfirmationStyle::default()
41                .label_style(label_style.clone())
42                .input_formatting(input_formatting.clone())
43                .submitted_formatting(submitted_formatting.clone()),
44        )
45        .display();
46
47    println!("Name: {:?}", name);
48    println!("Coffee: {:?}", coffee);
49
50    Ok(())
51}
pub fn print( &self, text: impl Into<String>, cmd_buffer: &mut impl CommandBuffer, )

Prints the formatted prefix and the input text to the provided command buffer