pub struct MultiselectionStyle {
pub label_style: LabelStyle,
pub submitted_formatting: Formatting,
pub filter_formatting: Formatting,
pub help_message_formatting: Formatting,
pub marker: Marker,
pub highlighted_option_formatting: Formatting,
pub normal_option_formatting: Formatting,
}Expand description
Style for the Multiselection prompt
Fields
label_style: LabelStyleStyle for the prompt itself
submitted_formatting: FormattingFormatting for the user’s input when the prompt is completed
filter_formatting: FormattingFormatting for the filter string
help_message_formatting: FormattingFormatting for the help message
marker: MarkerMarker to use
highlighted_option_formatting: FormattingFormatting for the option that is currently highlighted
normal_option_formatting: FormattingFormatting for the option which is not currently highlighted
Implementations
Sourceimpl MultiselectionStyle
impl MultiselectionStyle
Sourcepub fn print_option(
&self,
option_text: &str,
is_selected: bool,
is_highlighted: bool,
commands: &mut impl CommandBuffer,
)
pub fn print_option( &self, option_text: &str, is_selected: bool, is_highlighted: bool, commands: &mut impl CommandBuffer, )
Prints the option with the given text along with the marker to the provided command buffer